From: Jeff King Date: Fri, 09 Sep 2016 20:34:06 GMT Subject: [PATCH v3 0/2] patch-id for merges Message-ID: <20160909203406.5j5pmom442yoe4su@sigill.intra.peff.net> In-Reply-To: <20160907220101.hwwutkiagfottbdd@sigill.intra.peff.net> On Wed, Sep 07, 2016 at 06:01:01PM -0400, Jeff King wrote: > Here's a re-roll of the series I posted at: > > http://public-inbox.org/git/20160907075346.z6wtmqnfc6bsunjb@sigill.intra.peff.net/ > > Basically, it drops the time for "format-patch --cherry-pick" on a > particular case from 3 minutes down to 3 seconds, by avoiding diffs > on merge commits. Compared to v1, it fixes the totally-broken handling > of commit_patch_id() pointed out by Johannes. > > [1/3]: patch-ids: turn off rename detection > [2/3]: diff_flush_patch_id: stop returning error result > [3/3]: patch-ids: use commit sha1 as patch-id for merge commits And here is v3. Besides commit-message fixups, it drops patch 2, and instead the third patch teaches commit_patch_id() to distinguish between errors and "no patch id". Frankly, I still like v2 better, but I do not feel like arguing with Johannes about it anymore. [1/2]: patch-ids: turn off rename detection [2/2]: patch-ids: define patch-id of merge commits as "null" -Peff